@@ -16,3 +16,7 @@ from mw_python_sdk.api_list import (
     list_datasets,
     list_all_datasets,
 )
+
+from mw_python_sdk.rag import (
+    rag_search
+)
\ No newline at end of file
